package Net::Async::Spotify::Object::Recommendations;

use strict;
use warnings;

our $VERSION = '0.001'; # VERSION
our $AUTHORITY = 'cpan:VNEALV'; # AUTHORITY

use mro;
use parent qw(Net::Async::Spotify::Object::Generated::Recommendations);

=encoding utf8

=head1 NAME

Net::Async::Spotify::Object::Recommendations - Package representing Main Spotify Recommendations Object

=head1 DESCRIPTION

Main module for an Autogenerated one L<Net::Async::Spotify::Object::Generated::Recommendations>.
Will hold all extra functionality for Spotify Recommendations Object

=head1 METHODS

=cut

1;
