use strict;
use warnings;

# this test was generated with Dist::Zilla::Plugin::Test::NoTabs 0.15

use Test::More 0.88;
use Test::NoTabs;

my @files = (
    'bin/spotify-cli.pl',
    'lib/Net/Async/Spotify.pm',
    'lib/Net/Async/Spotify.pod',
    'lib/Net/Async/Spotify/API.pm',
    'lib/Net/Async/Spotify/API/Albums.pm',
    'lib/Net/Async/Spotify/API/Albums.pod',
    'lib/Net/Async/Spotify/API/Artists.pm',
    'lib/Net/Async/Spotify/API/Artists.pod',
    'lib/Net/Async/Spotify/API/Base.pm',
    'lib/Net/Async/Spotify/API/Browse.pm',
    'lib/Net/Async/Spotify/API/Browse.pod',
    'lib/Net/Async/Spotify/API/Episodes.pm',
    'lib/Net/Async/Spotify/API/Episodes.pod',
    'lib/Net/Async/Spotify/API/Follow.pm',
    'lib/Net/Async/Spotify/API/Follow.pod',
    'lib/Net/Async/Spotify/API/Generated/Albums.pm',
    'lib/Net/Async/Spotify/API/Generated/Albums.pod',
    'lib/Net/Async/Spotify/API/Generated/Artists.pm',
    'lib/Net/Async/Spotify/API/Generated/Artists.pod',
    'lib/Net/Async/Spotify/API/Generated/Browse.pm',
    'lib/Net/Async/Spotify/API/Generated/Browse.pod',
    'lib/Net/Async/Spotify/API/Generated/Episodes.pm',
    'lib/Net/Async/Spotify/API/Generated/Episodes.pod',
    'lib/Net/Async/Spotify/API/Generated/Follow.pm',
    'lib/Net/Async/Spotify/API/Generated/Follow.pod',
    'lib/Net/Async/Spotify/API/Generated/Library.pm',
    'lib/Net/Async/Spotify/API/Generated/Library.pod',
    'lib/Net/Async/Spotify/API/Generated/Markets.pm',
    'lib/Net/Async/Spotify/API/Generated/Markets.pod',
    'lib/Net/Async/Spotify/API/Generated/Personalization.pm',
    'lib/Net/Async/Spotify/API/Generated/Personalization.pod',
    'lib/Net/Async/Spotify/API/Generated/Player.pm',
    'lib/Net/Async/Spotify/API/Generated/Player.pod',
    'lib/Net/Async/Spotify/API/Generated/Playlists.pm',
    'lib/Net/Async/Spotify/API/Generated/Playlists.pod',
    'lib/Net/Async/Spotify/API/Generated/Search.pm',
    'lib/Net/Async/Spotify/API/Generated/Search.pod',
    'lib/Net/Async/Spotify/API/Generated/Shows.pm',
    'lib/Net/Async/Spotify/API/Generated/Shows.pod',
    'lib/Net/Async/Spotify/API/Generated/Tracks.pm',
    'lib/Net/Async/Spotify/API/Generated/Tracks.pod',
    'lib/Net/Async/Spotify/API/Generated/Users.pm',
    'lib/Net/Async/Spotify/API/Generated/Users.pod',
    'lib/Net/Async/Spotify/API/Library.pm',
    'lib/Net/Async/Spotify/API/Library.pod',
    'lib/Net/Async/Spotify/API/Markets.pm',
    'lib/Net/Async/Spotify/API/Markets.pod',
    'lib/Net/Async/Spotify/API/Personalization.pm',
    'lib/Net/Async/Spotify/API/Personalization.pod',
    'lib/Net/Async/Spotify/API/Player.pm',
    'lib/Net/Async/Spotify/API/Player.pod',
    'lib/Net/Async/Spotify/API/Playlists.pm',
    'lib/Net/Async/Spotify/API/Playlists.pod',
    'lib/Net/Async/Spotify/API/Search.pm',
    'lib/Net/Async/Spotify/API/Search.pod',
    'lib/Net/Async/Spotify/API/Shows.pm',
    'lib/Net/Async/Spotify/API/Shows.pod',
    'lib/Net/Async/Spotify/API/Tracks.pm',
    'lib/Net/Async/Spotify/API/Tracks.pod',
    'lib/Net/Async/Spotify/API/Users.pm',
    'lib/Net/Async/Spotify/API/Users.pod',
    'lib/Net/Async/Spotify/Object.pm',
    'lib/Net/Async/Spotify/Object/Album.pm',
    'lib/Net/Async/Spotify/Object/Album.pod',
    'lib/Net/Async/Spotify/Object/AlbumRestriction.pm',
    'lib/Net/Async/Spotify/Object/AlbumRestriction.pod',
    'lib/Net/Async/Spotify/Object/Artist.pm',
    'lib/Net/Async/Spotify/Object/Artist.pod',
    'lib/Net/Async/Spotify/Object/AudioFeatures.pm',
    'lib/Net/Async/Spotify/Object/AudioFeatures.pod',
    'lib/Net/Async/Spotify/Object/Base.pm',
    'lib/Net/Async/Spotify/Object/Category.pm',
    'lib/Net/Async/Spotify/Object/Category.pod',
    'lib/Net/Async/Spotify/Object/Context.pm',
    'lib/Net/Async/Spotify/Object/Context.pod',
    'lib/Net/Async/Spotify/Object/Copyright.pm',
    'lib/Net/Async/Spotify/Object/Copyright.pod',
    'lib/Net/Async/Spotify/Object/CurrentlyPlaying.pm',
    'lib/Net/Async/Spotify/Object/CurrentlyPlaying.pod',
    'lib/Net/Async/Spotify/Object/CurrentlyPlayingContext.pm',
    'lib/Net/Async/Spotify/Object/CurrentlyPlayingContext.pod',
    'lib/Net/Async/Spotify/Object/Cursor.pm',
    'lib/Net/Async/Spotify/Object/Cursor.pod',
    'lib/Net/Async/Spotify/Object/CursorPaging.pm',
    'lib/Net/Async/Spotify/Object/CursorPaging.pod',
    'lib/Net/Async/Spotify/Object/Device.pm',
    'lib/Net/Async/Spotify/Object/Device.pod',
    'lib/Net/Async/Spotify/Object/Devices.pm',
    'lib/Net/Async/Spotify/Object/Devices.pod',
    'lib/Net/Async/Spotify/Object/Disallows.pm',
    'lib/Net/Async/Spotify/Object/Disallows.pod',
    'lib/Net/Async/Spotify/Object/Episode.pm',
    'lib/Net/Async/Spotify/Object/Episode.pod',
    'lib/Net/Async/Spotify/Object/EpisodeRestriction.pm',
    'lib/Net/Async/Spotify/Object/EpisodeRestriction.pod',
    'lib/Net/Async/Spotify/Object/Error.pm',
    'lib/Net/Async/Spotify/Object/Error.pod',
    'lib/Net/Async/Spotify/Object/ExplicitContentSettings.pm',
    'lib/Net/Async/Spotify/Object/ExplicitContentSettings.pod',
    'lib/Net/Async/Spotify/Object/ExternalId.pm',
    'lib/Net/Async/Spotify/Object/ExternalId.pod',
    'lib/Net/Async/Spotify/Object/ExternalUrl.pm',
    'lib/Net/Async/Spotify/Object/ExternalUrl.pod',
    'lib/Net/Async/Spotify/Object/Followers.pm',
    'lib/Net/Async/Spotify/Object/Followers.pod',
    'lib/Net/Async/Spotify/Object/General.pm',
    'lib/Net/Async/Spotify/Object/Generated/Album.pm',
    'lib/Net/Async/Spotify/Object/Generated/Album.pod',
    'lib/Net/Async/Spotify/Object/Generated/AlbumRestriction.pm',
    'lib/Net/Async/Spotify/Object/Generated/AlbumRestriction.pod',
    'lib/Net/Async/Spotify/Object/Generated/Artist.pm',
    'lib/Net/Async/Spotify/Object/Generated/Artist.pod',
    'lib/Net/Async/Spotify/Object/Generated/AudioFeatures.pm',
    'lib/Net/Async/Spotify/Object/Generated/AudioFeatures.pod',
    'lib/Net/Async/Spotify/Object/Generated/Category.pm',
    'lib/Net/Async/Spotify/Object/Generated/Category.pod',
    'lib/Net/Async/Spotify/Object/Generated/Context.pm',
    'lib/Net/Async/Spotify/Object/Generated/Context.pod',
    'lib/Net/Async/Spotify/Object/Generated/Copyright.pm',
    'lib/Net/Async/Spotify/Object/Generated/Copyright.pod',
    'lib/Net/Async/Spotify/Object/Generated/CurrentlyPlaying.pm',
    'lib/Net/Async/Spotify/Object/Generated/CurrentlyPlaying.pod',
    'lib/Net/Async/Spotify/Object/Generated/CurrentlyPlayingContext.pm',
    'lib/Net/Async/Spotify/Object/Generated/CurrentlyPlayingContext.pod',
    'lib/Net/Async/Spotify/Object/Generated/Cursor.pm',
    'lib/Net/Async/Spotify/Object/Generated/Cursor.pod',
    'lib/Net/Async/Spotify/Object/Generated/CursorPaging.pm',
    'lib/Net/Async/Spotify/Object/Generated/CursorPaging.pod',
    'lib/Net/Async/Spotify/Object/Generated/Device.pm',
    'lib/Net/Async/Spotify/Object/Generated/Device.pod',
    'lib/Net/Async/Spotify/Object/Generated/Devices.pm',
    'lib/Net/Async/Spotify/Object/Generated/Devices.pod',
    'lib/Net/Async/Spotify/Object/Generated/Disallows.pm',
    'lib/Net/Async/Spotify/Object/Generated/Disallows.pod',
    'lib/Net/Async/Spotify/Object/Generated/Episode.pm',
    'lib/Net/Async/Spotify/Object/Generated/Episode.pod',
    'lib/Net/Async/Spotify/Object/Generated/EpisodeRestriction.pm',
    'lib/Net/Async/Spotify/Object/Generated/EpisodeRestriction.pod',
    'lib/Net/Async/Spotify/Object/Generated/Error.pm',
    'lib/Net/Async/Spotify/Object/Generated/Error.pod',
    'lib/Net/Async/Spotify/Object/Generated/ExplicitContentSettings.pm',
    'lib/Net/Async/Spotify/Object/Generated/ExplicitContentSettings.pod',
    'lib/Net/Async/Spotify/Object/Generated/ExternalId.pm',
    'lib/Net/Async/Spotify/Object/Generated/ExternalId.pod',
    'lib/Net/Async/Spotify/Object/Generated/ExternalUrl.pm',
    'lib/Net/Async/Spotify/Object/Generated/ExternalUrl.pod',
    'lib/Net/Async/Spotify/Object/Generated/Followers.pm',
    'lib/Net/Async/Spotify/Object/Generated/Followers.pod',
    'lib/Net/Async/Spotify/Object/Generated/Image.pm',
    'lib/Net/Async/Spotify/Object/Generated/Image.pod',
    'lib/Net/Async/Spotify/Object/Generated/LinkedTrack.pm',
    'lib/Net/Async/Spotify/Object/Generated/LinkedTrack.pod',
    'lib/Net/Async/Spotify/Object/Generated/Paging.pm',
    'lib/Net/Async/Spotify/Object/Generated/Paging.pod',
    'lib/Net/Async/Spotify/Object/Generated/PlayHistory.pm',
    'lib/Net/Async/Spotify/Object/Generated/PlayHistory.pod',
    'lib/Net/Async/Spotify/Object/Generated/PlayerError.pm',
    'lib/Net/Async/Spotify/Object/Generated/PlayerError.pod',
    'lib/Net/Async/Spotify/Object/Generated/Playlist.pm',
    'lib/Net/Async/Spotify/Object/Generated/Playlist.pod',
    'lib/Net/Async/Spotify/Object/Generated/PlaylistTrack.pm',
    'lib/Net/Async/Spotify/Object/Generated/PlaylistTrack.pod',
    'lib/Net/Async/Spotify/Object/Generated/PlaylistTracksRef.pm',
    'lib/Net/Async/Spotify/Object/Generated/PlaylistTracksRef.pod',
    'lib/Net/Async/Spotify/Object/Generated/PrivateUser.pm',
    'lib/Net/Async/Spotify/Object/Generated/PrivateUser.pod',
    'lib/Net/Async/Spotify/Object/Generated/PublicUser.pm',
    'lib/Net/Async/Spotify/Object/Generated/PublicUser.pod',
    'lib/Net/Async/Spotify/Object/Generated/RecommendationSeed.pm',
    'lib/Net/Async/Spotify/Object/Generated/RecommendationSeed.pod',
    'lib/Net/Async/Spotify/Object/Generated/Recommendations.pm',
    'lib/Net/Async/Spotify/Object/Generated/Recommendations.pod',
    'lib/Net/Async/Spotify/Object/Generated/ResumePoint.pm',
    'lib/Net/Async/Spotify/Object/Generated/ResumePoint.pod',
    'lib/Net/Async/Spotify/Object/Generated/SavedAlbum.pm',
    'lib/Net/Async/Spotify/Object/Generated/SavedAlbum.pod',
    'lib/Net/Async/Spotify/Object/Generated/SavedEpisode.pm',
    'lib/Net/Async/Spotify/Object/Generated/SavedEpisode.pod',
    'lib/Net/Async/Spotify/Object/Generated/SavedShow.pm',
    'lib/Net/Async/Spotify/Object/Generated/SavedShow.pod',
    'lib/Net/Async/Spotify/Object/Generated/SavedTrack.pm',
    'lib/Net/Async/Spotify/Object/Generated/SavedTrack.pod',
    'lib/Net/Async/Spotify/Object/Generated/Show.pm',
    'lib/Net/Async/Spotify/Object/Generated/Show.pod',
    'lib/Net/Async/Spotify/Object/Generated/SimplifiedAlbum.pm',
    'lib/Net/Async/Spotify/Object/Generated/SimplifiedAlbum.pod',
    'lib/Net/Async/Spotify/Object/Generated/SimplifiedArtist.pm',
    'lib/Net/Async/Spotify/Object/Generated/SimplifiedArtist.pod',
    'lib/Net/Async/Spotify/Object/Generated/SimplifiedEpisode.pm',
    'lib/Net/Async/Spotify/Object/Generated/SimplifiedEpisode.pod',
    'lib/Net/Async/Spotify/Object/Generated/SimplifiedPlaylist.pm',
    'lib/Net/Async/Spotify/Object/Generated/SimplifiedPlaylist.pod',
    'lib/Net/Async/Spotify/Object/Generated/SimplifiedShow.pm',
    'lib/Net/Async/Spotify/Object/Generated/SimplifiedShow.pod',
    'lib/Net/Async/Spotify/Object/Generated/SimplifiedTrack.pm',
    'lib/Net/Async/Spotify/Object/Generated/SimplifiedTrack.pod',
    'lib/Net/Async/Spotify/Object/Generated/Track.pm',
    'lib/Net/Async/Spotify/Object/Generated/Track.pod',
    'lib/Net/Async/Spotify/Object/Generated/TrackRestriction.pm',
    'lib/Net/Async/Spotify/Object/Generated/TrackRestriction.pod',
    'lib/Net/Async/Spotify/Object/Generated/TuneableTrack.pm',
    'lib/Net/Async/Spotify/Object/Generated/TuneableTrack.pod',
    'lib/Net/Async/Spotify/Object/Image.pm',
    'lib/Net/Async/Spotify/Object/Image.pod',
    'lib/Net/Async/Spotify/Object/LinkedTrack.pm',
    'lib/Net/Async/Spotify/Object/LinkedTrack.pod',
    'lib/Net/Async/Spotify/Object/Paging.pm',
    'lib/Net/Async/Spotify/Object/Paging.pod',
    'lib/Net/Async/Spotify/Object/PlayHistory.pm',
    'lib/Net/Async/Spotify/Object/PlayHistory.pod',
    'lib/Net/Async/Spotify/Object/PlayerError.pm',
    'lib/Net/Async/Spotify/Object/PlayerError.pod',
    'lib/Net/Async/Spotify/Object/Playlist.pm',
    'lib/Net/Async/Spotify/Object/Playlist.pod',
    'lib/Net/Async/Spotify/Object/PlaylistTrack.pm',
    'lib/Net/Async/Spotify/Object/PlaylistTrack.pod',
    'lib/Net/Async/Spotify/Object/PlaylistTracksRef.pm',
    'lib/Net/Async/Spotify/Object/PlaylistTracksRef.pod',
    'lib/Net/Async/Spotify/Object/PrivateUser.pm',
    'lib/Net/Async/Spotify/Object/PrivateUser.pod',
    'lib/Net/Async/Spotify/Object/PublicUser.pm',
    'lib/Net/Async/Spotify/Object/PublicUser.pod',
    'lib/Net/Async/Spotify/Object/RecommendationSeed.pm',
    'lib/Net/Async/Spotify/Object/RecommendationSeed.pod',
    'lib/Net/Async/Spotify/Object/Recommendations.pm',
    'lib/Net/Async/Spotify/Object/Recommendations.pod',
    'lib/Net/Async/Spotify/Object/ResumePoint.pm',
    'lib/Net/Async/Spotify/Object/ResumePoint.pod',
    'lib/Net/Async/Spotify/Object/SavedAlbum.pm',
    'lib/Net/Async/Spotify/Object/SavedAlbum.pod',
    'lib/Net/Async/Spotify/Object/SavedEpisode.pm',
    'lib/Net/Async/Spotify/Object/SavedEpisode.pod',
    'lib/Net/Async/Spotify/Object/SavedShow.pm',
    'lib/Net/Async/Spotify/Object/SavedShow.pod',
    'lib/Net/Async/Spotify/Object/SavedTrack.pm',
    'lib/Net/Async/Spotify/Object/SavedTrack.pod',
    'lib/Net/Async/Spotify/Object/Show.pm',
    'lib/Net/Async/Spotify/Object/Show.pod',
    'lib/Net/Async/Spotify/Object/SimplifiedAlbum.pm',
    'lib/Net/Async/Spotify/Object/SimplifiedAlbum.pod',
    'lib/Net/Async/Spotify/Object/SimplifiedArtist.pm',
    'lib/Net/Async/Spotify/Object/SimplifiedArtist.pod',
    'lib/Net/Async/Spotify/Object/SimplifiedEpisode.pm',
    'lib/Net/Async/Spotify/Object/SimplifiedEpisode.pod',
    'lib/Net/Async/Spotify/Object/SimplifiedPlaylist.pm',
    'lib/Net/Async/Spotify/Object/SimplifiedPlaylist.pod',
    'lib/Net/Async/Spotify/Object/SimplifiedShow.pm',
    'lib/Net/Async/Spotify/Object/SimplifiedShow.pod',
    'lib/Net/Async/Spotify/Object/SimplifiedTrack.pm',
    'lib/Net/Async/Spotify/Object/SimplifiedTrack.pod',
    'lib/Net/Async/Spotify/Object/Track.pm',
    'lib/Net/Async/Spotify/Object/Track.pod',
    'lib/Net/Async/Spotify/Object/TrackRestriction.pm',
    'lib/Net/Async/Spotify/Object/TrackRestriction.pod',
    'lib/Net/Async/Spotify/Object/TuneableTrack.pm',
    'lib/Net/Async/Spotify/Object/TuneableTrack.pod',
    'lib/Net/Async/Spotify/Scope.pm',
    'lib/Net/Async/Spotify/Token.pm',
    'lib/Net/Async/Spotify/Util.pm',
    't/00-check-deps.t',
    't/00-compile.t',
    't/00-report-prereqs.dd',
    't/00-report-prereqs.t',
    'xt/author/distmeta.t',
    'xt/author/eol.t',
    'xt/author/minimum-version.t',
    'xt/author/mojibake.t',
    'xt/author/no-tabs.t',
    'xt/author/pod-syntax.t',
    'xt/author/portability.t',
    'xt/author/test-version.t',
    'xt/release/common_spelling.t',
    'xt/release/cpan-changes.t'
);

notabs_ok($_) foreach @files;
done_testing;
