package Net::Async::Spotify::Object::SavedTrack;

use strict;
use warnings;

our $VERSION = '0.001'; # VERSION
our $AUTHORITY = 'cpan:VNEALV'; # AUTHORITY

use mro;
use parent qw(Net::Async::Spotify::Object::Generated::SavedTrack);

=encoding utf8

=head1 NAME

Net::Async::Spotify::Object::SavedTrack - Package representing Main Spotify SavedTrack Object

=head1 DESCRIPTION

Main module for an Autogenerated one L<Net::Async::Spotify::Object::Generated::SavedTrack>.
Will hold all extra functionality for Spotify SavedTrack Object

=head1 METHODS

=cut

1;
